.. rst-class:: detail

MoveToFrame
======================

.. currentmodule:: compas_rrc

.. autoclass:: MoveToFrame

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~MoveToFrame.__init__
        ~MoveToFrame.from_msg
    
    